@@ -10,10 +10,13 @@ ft2m <- function(x) {
 #' @param harmonics The harmonics object.
 #' @export
 tide_stations <- function(stations = ".*", harmonics = rtide::harmonics) {
-  check_vector(stations, "")
+  chk_s3_class(stations, "character")
+  chk_not_empty(stations)
+  chk_not_any_na(stations)
   check_tide_harmonics(harmonics)
-  if (!is.tide_harmonics(harmonics))
+  if (!is.tide_harmonics(harmonics)) {
     stop("harmonics must be an object of class 'tide_harmonics'", call. = FALSE)
+  }
 
   stations <- gsub("[(]", "[(]", stations)
   stations <- gsub("[)]", "[)]", stations)
@@ -40,45 +43,51 @@ tide_stations <- function(stations = ".*", harmonics = rtide::harmonics) {
 #' tide_datetimes()
 tide_datetimes <- function(minutes = 60L, from = as.Date("2015-01-01"), to = as.Date("2015-12-31"),
                            tz = "PST8PDT") {
+  chk_number(minutes)
+  chk_range(minutes, c(1, 60))
 
-  if (class(minutes) == "numeric"){
-    check_vector(minutes, c(1,60), length = 1)
-    if (minutes %% 1 != 0)	# If modulo isn't 0, decimal value is present
-      warning("Truncating minutes interval to whole number", call.=FALSE)
+  if (class(minutes) == "numeric") {
+    if (minutes %% 1 != 0) { # If modulo isn't 0, decimal value is present
+      warning("Truncating minutes interval to whole number", call. = FALSE)
+    }
     minutes <- as.integer(minutes)
   }
-  check_vector(minutes, c(1L, 60L), length = 1)
 
-  check_date(from)
-  check_date(to)
-  check_string(tz)
+  chk_date(from)
+  chk_date(to)
+  chk_tz(tz)
 
-  from <- ISOdatetime(year = lubridate::year(from), month = lubridate::month(from),
-                      day = lubridate::day(from), hour = 0, min = 0, sec = 0, tz = tz)
-  to <- ISOdatetime(year = lubridate::year(to), month = lubridate::month(to),
-                    day = lubridate::day(to), hour = 23, min = 59, sec = 59, tz = tz)
+  from <- ISOdatetime(
+    year = dtt_year(from), month = dtt_month(from),
+    day = dtt_day(from), hour = 0, min = 0, sec = 0, tz = tz
+  )
+  to <- ISOdatetime(
+    year = dtt_year(to), month = dtt_month(to),
+    day = dtt_day(to), hour = 23, min = 59, sec = 59, tz = tz
+  )
 
   seq(from, to, by = paste(minutes, "min"))
 }
 
 hours_year <- function(datetime) {
-  check_vector(datetime, Sys.time())
-  stopifnot(identical(lubridate::tz(datetime), "UTC"))
+  chk_s3_class(datetime, "POSIXct")
+  chk_not_any_na(datetime)
+  stopifnot(identical(dtt_tz(datetime), "UTC"))
 
-  year <- lubridate::year(datetime)
+  year <- dtt_year(datetime)
 
   startdatetime <- ISOdate(year, 1, 1, 0, tz = "UTC")
-  hours <- difftime(datetime, startdatetime, units = 'hours')
+  hours <- difftime(datetime, startdatetime, units = "hours")
   hours <- as.numeric(hours)
   hours
 }
 
 tide_height_datetime <- function(d, h) {
-  h$NodeYear <- h$NodeYear[,as.character(lubridate::year(d)),,drop = FALSE]
+  h$NodeYear <- h$NodeYear[, as.character(dtt_year(d)), , drop = FALSE]
 
-  height <- h$Station$Datum + sum(h$NodeYear[,,"NodeFactor"] * h$StationNode[,,"A"] *
-                                    cos((h$Node$Speed * (hours_year(d) - h$Station$Hours) +
-                                           h$NodeYear[,,"EquilArg"] - h$StationNode[,,"Kappa"]) * pi/180))
+  height <- h$Station$Datum + sum(h$NodeYear[, , "NodeFactor"] * h$StationNode[, , "A"] *
+    cos((h$Node$Speed * (hours_year(d) - h$Station$Hours) +
+      h$NodeYear[, , "EquilArg"] - h$StationNode[, , "Kappa"]) * pi / 180))
 
   height
 }
@@ -92,10 +101,10 @@ tide_height_data_station <- function(data, harmonics) {
   harmonics <- subset(harmonics, paste0("^", data$Station[1], "$"))
   data <- split(data, 1:nrow(data))
   data <- lapply(data, FUN = tide_height_data_datetime, h = harmonics)
-  data$stringsAsFactors <- FALSE
   data <- do.call("rbind", data)
-  if (harmonics$Station$Units %in% c("feet", "ft"))
+  if (harmonics$Station$Units %in% c("feet", "ft")) {
     data$TideHeight <- ft2m(data$TideHeight)
+  }
   data
 }
 
@@ -109,31 +118,37 @@ tide_height_data_station <- function(data, harmonics) {
 #' @return A data frame of the tide heights in m.
 #' @export
 tide_height_data <- function(data, harmonics = rtide::harmonics) {
-  check_data(data, values = list(Station = "", DateTime = Sys.time()),
-             nrow = c(1L, .Machine$integer.max))
+  check_data(data,
+    values = list(Station = "", DateTime = Sys.time()),
+    nrow = c(1L, .Machine$integer.max)
+  )
 
-  if (!all(data$Station %in% tide_stations(harmonics = harmonics)))
+  if (!all(data$Station %in% tide_stations(harmonics = harmonics))) {
     stop("unrecognised stations", call. = FALSE)
+  }
 
-  if (has_name(data, "TideHeight"))
+  if (has_name(data, "TideHeight")) {
     stop("data already has 'TideHeight' column", call. = FALSE)
+  }
 
-  tz <- lubridate::tz(data$DateTime)
-  data$DateTime <- lubridate::with_tz(data$DateTime, tzone = "UTC")
+  tz <- dtt_tz(data$DateTime)
+  data$DateTime <- dtt_adjust_tz(data$DateTime, tz = "UTC")
 
-  years <- range(lubridate::year(data$DateTime), na.rm = TRUE)
-  if (!all(years %in% years_tide_harmonics(harmonics)))
+  years <- range(dtt_year(data$DateTime), na.rm = TRUE)
+  if (!all(years %in% years_tide_harmonics(harmonics))) {
     stop("years are outside harmonics range", call. = FALSE)
+  }
 
   station <- data$Station
   data <- split(data, station)
   data <- lapply(data, FUN = tide_height_data_station, harmonics = harmonics)
-  data$stringsAsFactors <- FALSE
+  op <- options(stringsAsFactors = FALSE)
+  on.exit(options(op))
   data <- do.call("rbind", data)
 
-  data$DateTime <- lubridate::with_tz(data$DateTime, tzone = tz)
-  data <- data[order(data$Station, data$DateTime),]
-  as_conditional_tibble(data)
+  data$DateTime <- dtt_adjust_tz(data$DateTime, tz = tz)
+  data <- data[order(data$Station, data$DateTime), ]
+  tibble::as_tibble(data)
 }
 
 #' Tide Height
@@ -145,9 +160,9 @@ tide_height_data <- function(data, harmonics = rtide::harmonics) {
 #' @return A data frame of the tide heights in m by the number of minutes for each station from from to to.
 #' @export
 tide_height <- function(
-  stations = "Monterey Harbor", minutes = 60L,
-  from = as.Date("2015-01-01"), to = as.Date("2015-01-01"), tz = "UTC",
-  harmonics = rtide::harmonics) {
+                        stations = "Monterey Harbor", minutes = 60L,
+                        from = as.Date("2015-01-01"), to = as.Date("2015-01-01"), tz = "UTC",
+                        harmonics = rtide::harmonics) {
   stations <- tide_stations(stations, harmonics)
   datetimes <- tide_datetimes(minutes = minutes, from = from, to = to, tz = tz)
 
